"""CLI - Command Line Interface"""
import snakypy
from snakypy import FG
from zshpower import decorators, utils
from zshpower import HOME, __pkginfo__, __version__
from zshpower.zshpower import ZSHPower

zp = ZSHPower(HOME)


@decorators.assign_cli(zp.arguments(), "init")
def init():
    zp.init_command(reload=True, message=True)


@decorators.assign_cli(zp.arguments(), "config")
def config_action():
    zp.config_command()


@decorators.assign_cli(zp.arguments(), "activate")
def activate():
    zp.activate_command()


@decorators.assign_cli(zp.arguments(), "deactivate")
def deactivate():
    zp.deactivate_command()


@decorators.assign_cli(zp.arguments(), "reset")
def reset_config():
    zp.reset_command()


@decorators.assign_cli(zp.arguments(), "uninstall")
def uninstall():
    zp.uninstall_command()


@decorators.assign_cli(zp.arguments(), "--credits")
def credence():
    utils.show_billboard()
    snakypy.console.credence(
        __pkginfo__["name"],
        __version__,
        __pkginfo__["home_page"],
        __pkginfo__,
        foreground=FG.CYAN,
    )


def main():
    init()
    config_action()
    activate()
    deactivate()
    reset_config()
    uninstall()
    credence()



import snakypy
import os
import re
import shutil
import subprocess

try:
    import pwd
except ImportError:
    pass
import tomlkit
from os.path import join, exists, isdir, isfile
from datetime import datetime
from sys import platform
from snakypy import printer, FG
from zshpower import HOME, __pkginfo__
from zipfile import ZipFile


def show_billboard():
    """Function to create a billboard."""
    print("\n")
    printer("Offered by:".center(50), foreground=FG.GREEN)
    snakypy.console.billboard(
        __pkginfo__["organization_name"], justify="center", foreground=FG.YELLOW
    )
    printer(f"copyright (c) since 2020\n".center(100), foreground=FG.GREEN)


def tools_requirements(*args):
    for tool in args:
        if shutil.which(tool) is None:
            raise Exception(
                f'The package \'{__pkginfo__["name"]}\' needs the "{tool}" tool.'
                " Tool not found. Aborted."
            )


def checking_init(root):
    """Function that ends commands that depend on the created repository, but
    the repository was not created."""
    if not exists(join(root, f"{__pkginfo__['pkg_name']}.zsh-theme")):
        printer(
            f'Command "{__pkginfo__["pkg_name"]} init" has not been started.' "Aborted",
            foreground=FG.WARNING,
        )
        exit(1)
    return True


def create_config(content, file_path, force=False):
    if not exists(file_path) or force:
        parsed_toml = tomlkit.parse(content)
        write_toml = tomlkit.dumps(parsed_toml)
        snakypy.file.create(write_toml, file_path, force=force)
        return True
    return


def read_zshrc(zsh_rc):
    """ """
    if exists(zsh_rc):
        with open(zsh_rc) as r:
            content_ = r.read()
        m = re.search(r"ZSH_THEME=\".*", content_)
        if m is not None:
            zsh_theme = m.group(0)
            lst = zsh_theme.split("=")
            theme_name = [s.strip('"') for s in lst][1]
            return theme_name, content_, zsh_theme
    return False


def create_zshrc(content_, zsh_rc):
    if exists(zsh_rc):
        if not read_zshrc(zsh_rc):
            shutil.copyfile(zsh_rc, f"{zsh_rc}-D{datetime.today().isoformat()}")
            snakypy.file.create(content_, zsh_rc, force=True)
            return True
    elif not exists(zsh_rc):
        snakypy.file.create(content_, zsh_rc)
        return True
    return


def plugins_current_zshrc(zsh_rc):
    content_ = read_zshrc(zsh_rc)[1]
    m = re.search(r"^plugins=\(.*", content_, flags=re.M)
    if m is not None:
        get = m.group(0)
        lst = get.split("=")
        current = [i.strip('"').replace("(", "").replace(")", "") for i in lst][1]
        return current.split()


def add_plugins_zshrc(zsh_rc):
    plugins = (
        "python",
        "django",
        "pip",
        "pep8",
        "autopep8",
        "zsh-syntax-highlighting",
        "zsh-autosuggestions",
    )
    current = plugins_current_zshrc(zsh_rc)
    new_plugins = []
    for plugin in plugins:
        if plugin not in current:
            new_plugins.append(plugin)

    if len(new_plugins) > 0:
        plugins = f'plugins=({" ".join(current)} {" ".join(new_plugins)})'
        new_zsh_rc = re.sub(
            rf"^plugins=\(.*", plugins, read_zshrc(zsh_rc)[1], flags=re.M
        )
        snakypy.file.create(new_zsh_rc, zsh_rc, force=True)
        return new_zsh_rc
    return


def change_theme_in_zshrc(zsh_rc, theme_name):
    if read_zshrc(zsh_rc):
        current_theme = read_zshrc(zsh_rc)[2]
        new_theme = f'ZSH_THEME="{theme_name}"'
        new_zsh_rc = re.sub(
            rf"{current_theme}", new_theme, read_zshrc(zsh_rc)[1], flags=re.M
        )
        snakypy.file.create(new_zsh_rc, zsh_rc, force=True)
        return True
    return


def reload_zsh():
    subprocess.call("exec zsh", shell=True)


def bash_command(cmd):
    subprocess.Popen(["/bin/bash", "-c", cmd])


def current_shell():
    pw = pwd.getpwuid(os.getuid())
    path_shell = pw[-1]
    shell = str(path_shell).split("/")[-1]
    return shell, path_shell


def current_user():
    return str(os.popen("whoami").read()).replace("\n", "")


def change_shell():
    if current_shell()[0] != "zsh":
        try:
            subprocess.call(f"chsh -s $(which zsh) {current_user()}", shell=True)
        except KeyboardInterrupt:
            printer("Canceled by user", foreground=FG.WARNING)


def omz_install(omz_root):
    omz_github = "https://github.com/ohmyzsh/ohmyzsh.git"
    cmd_line = f"git clone {omz_github} {omz_root}"
    try:
        if not exists(omz_root):
            printer("Install Oh My ZSH...", foreground=FG.QUESTION)
            snakypy.console.cmd(cmd_line, verbose=True)
            printer(
                "Oh My ZSH installation process finished.", foreground=FG.FINISH,
            )

    except Exception:
        raise Exception("Error downloading Oh My ZSH. Aborted!")


def omz_install_plugins(omz_root, plugins):
    try:
        url_master = "https://github.com/zsh-users"
        for plugin in plugins:
            path = join(omz_root, f"custom/plugins/{plugin}")
            clone = f"git clone {url_master}/{plugin}.git {path}"
            if not isdir(path):
                printer(f"Install plugins {plugin}...", foreground=FG.QUESTION)
                snakypy.console.cmd(clone, verbose=True)
                printer(f"Plugin {plugin} task finished!", foreground=FG.FINISH)
    except Exception:
        raise Exception(f"There was an error installing the plugin")


def install_fonts(force=False):
    url = "https://github.com/snakypy/snakypy-static"
    base_url = f"blob/master/zshpower/fonts/fonts.zip?raw=true"
    font_name = "DejaVu Sans Mono Nerd Font"
    fonts_dir = join(HOME, f".fonts")
    snakypy.path.create(fonts_dir)
    curl_output = join(HOME, "zshpower__font.zip")

    if platform.startswith("linux"):
        try:
            if (
                not isfile(join(fonts_dir, "DejaVu Sans Mono Nerd Font Complete.ttf"))
                or force
            ):
                printer(
                    f'Please wait, downloading the "{font_name}" font and'
                    "installing...",
                    foreground=FG.QUESTION,
                )
                cmd_line = f"curl -L {join(url, base_url)} -o {curl_output}"
                snakypy.console.cmd(cmd_line, verbose=True)

                with ZipFile(curl_output, "r") as zip_ref:
                    zip_ref.extractall(fonts_dir)
                    os.remove(curl_output)
                    printer("Done!", foreground=FG.FINISH)
                return True
            return
        except Exception as err:
            raise Exception(f'Error downloading font "{font_name}"', err)
    return



"""Main module."""
import os
import shutil
import contextlib
import pydoc
import subprocess
import snakypy
from sys import exit
from textwrap import dedent
from datetime import datetime
from zshpower import __version__, __pkginfo__
from zshpower import utils, config
from snakypy import printer, FG, pick
from docopt import docopt
from snakypy.ansi import NONE
from os.path import join


class ZSHPower:
    def __init__(self, home):
        self.HOME = home
        self.config_root = join(self.HOME, f".config/snakypy/zshpower/{__version__}")
        self.config = join(self.config_root, "config.toml")
        self.zsh_rc = join(self.HOME, ".zshrc")
        self.omz_root = join(self.HOME, ".oh-my-zsh")
        self.themes_folder = join(self.omz_root, "custom/themes")
        self.theme_file = join(
            self.themes_folder, f"{__pkginfo__['pkg_name']}.zsh-theme"
        )
        self.plugins = ("zsh-syntax-highlighting", "zsh-autosuggestions")
        robbyrussell = f"{FG.MAGENTA}robbyrussell{NONE}"
        self.menu_opts = dedent(
            f"""
        {FG.MAGENTA}Welcome to the {__pkginfo__["pkg_name"]} options menu.{NONE}

        Usage:
            {__pkginfo__['executable']} init
            {__pkginfo__['executable']} config (--open | --view)
            {__pkginfo__['executable']} activate
            {__pkginfo__['executable']} deactivate [--theme=<name>]
            {__pkginfo__['executable']} reset
            {__pkginfo__['executable']} uninstall
            {__pkginfo__['executable']} --help
            {__pkginfo__['executable']} --version
            {__pkginfo__['executable']} --credits

        Arguments:
            {FG.CYAN}init{NONE} ---------- Install dependencies like Oh My ZSH and plugins and activate the
                            {__pkginfo__["name"]} theme.
            {FG.CYAN}activate{NONE} ------ Activate the {__pkginfo__["name"]} theme.
            {FG.CYAN}deactivate{NONE} ---- Deactivate the {__pkginfo__["name"]} theme and go back to the default.
            {FG.CYAN}reset{NONE} --------- Reset to default settings.
            {FG.CYAN}uninstall{NONE} ----- Uninstall the package {__pkginfo__["name"]}.
            {FG.CYAN}config{NONE} -------- The easiest way to edit and view the settings is through this option.

        Options:
            {FG.CYAN}--help{NONE} --------- Show this screen.
            {FG.CYAN}--open{NONE} --------- Open the configuration file in edit mode and perform the automatic update
                             when you exit.
            {FG.CYAN}--view{NONE} --------- View the configuration file on the terminal.
            {FG.CYAN}--theme=<name>{NONE} - Get the name of a theme available on Oh My ZSH [Default: {robbyrussell}].
            {FG.CYAN}--version{NONE} ------ Show version.
            {FG.CYAN}--credits{NONE} ------ Show credits.
                """
        )

    def arguments(self, argv=None):
        formatted_version = (
            f"{__pkginfo__['name']} version: {FG.CYAN}{__version__}{NONE}"
        )
        data = docopt(self.menu_opts, argv=argv, version=formatted_version)
        return data

    def init_command(self, reload=False, message=False):
        utils.tools_requirements("git", "vim", "zsh")
        snakypy.path.create(self.config_root)
        utils.create_config(config.config_content(), self.config)
        utils.omz_install(self.omz_root)
        utils.omz_install_plugins(self.omz_root, self.plugins)
        utils.install_fonts()
        utils.create_zshrc(config.zshrc_content(self.omz_root), self.zsh_rc)
        utils.change_theme_in_zshrc(self.zsh_rc, "zshpower")
        utils.add_plugins_zshrc(self.zsh_rc)
        snakypy.file.create(config.theme_content(), self.theme_file, force=True)
        utils.change_shell()
        printer("Done!", foreground=FG.FINISH) if message else None
        utils.reload_zsh() if reload else None

    def config_command(self):
        utils.checking_init(self.themes_folder)

        if self.arguments()["--open"]:
            editors = ("vim", "nano", "emacs")
            for editor in editors:
                if shutil.which(editor):
                    get_editor = os.environ.get("EDITOR", editor)
                    with open(self.config) as f:
                        subprocess.call([get_editor, f.name])
                    return True
        elif self.arguments()["--view"]:
            read_config = snakypy.file.read(self.config)
            pydoc.pager(read_config)
            return True

    def activate_command(self):
        utils.checking_init(self.themes_folder)

        if utils.read_zshrc(self.zsh_rc)[0] == "zshpower":
            printer("Already activated. Nothing to do.", foreground=FG.GREEN)
            exit(0)
        utils.change_theme_in_zshrc(self.zsh_rc, "zshpower")
        printer("Activation process finish.", foreground=FG.FINISH)
        utils.reload_zsh()

    def deactivate_command(self, *, theme_name="robbyrussell"):
        utils.checking_init(self.themes_folder)

        if not utils.read_zshrc(self.zsh_rc)[0] == "zshpower":
            printer("Already disabled. Nothing to do.", foreground=FG.GREEN)
            exit(0)
        if not self.arguments()["--theme"]:
            utils.change_theme_in_zshrc(self.zsh_rc, theme_name)
        else:
            utils.change_theme_in_zshrc(self.zsh_rc, self.arguments()["--theme"])
        printer("Deactivation process finish.", foreground=FG.FINISH)
        utils.reload_zsh()

    def reset_command(self):
        utils.checking_init(self.themes_folder)
        utils.create_config(config.config_content(), self.config, force=True)
        printer("Reset process finished.", foreground=FG.FINISH)
        utils.reload_zsh()

    def uninstall_command(self):
        utils.checking_init(self.themes_folder)

        title = f"What did you want to uninstall?"
        options = [
            f"{__pkginfo__['name']}",
            f"{__pkginfo__['name']} and Oh My ZSH",
            "None",
        ]
        reply = pick(title, options, colorful=True, index=True)

        if reply is None or reply[0] == 2:
            printer("Whew! Thanks! :)", foreground=FG.GREEN)
            exit(0)

        with contextlib.suppress(Exception):
            os.remove(self.theme_file)

        pip_check = shutil.which("pip")
        if pip_check is not None:
            subprocess.check_output(
                f'pip uninstall {__pkginfo__["name"]} -y',
                shell=True,
                universal_newlines=True,
            )
        utils.change_theme_in_zshrc(self.zsh_rc, "robbyrussell")

        if reply[0] == 1:
            shutil.rmtree(self.omz_root, ignore_errors=True)
            with contextlib.suppress(Exception):
                shutil.copyfile(
                    self.zsh_rc, f"{self.zsh_rc}-D{datetime.today().isoformat()}"
                )
            with contextlib.suppress(Exception):
                os.remove(self.zsh_rc)

        utils.reload_zsh()

        printer("Uninstall process finished.", foreground=FG.FINISH)



"""
ZSHPower
~~~~~~~~

ZSHPower is a theme with a manager for the Oh My ZSH framework.


For more information, access: 'https://github.com/snakypy/zshpower'

:copyright: Copyright 2020-2020 by Snakypy team, see AUTHORS.
:license: MIT license, see LICENSE for details.
"""

from . import __name__
from pathlib import Path

HOME = str(Path.home())
__version__ = "0.2.5"
__pkginfo__ = {
    "name": "ZSHPower",
    "description": "ZSHPower is a theme with a manager for the Oh My ZSH framework.",
    "pkg_name": __name__,
    "executable": __name__,
    "home_page": "https://github.com/snakypy/zshpower",
    "organization_name": "Snakypy",
    "author": {
        "name": "William C. Canin",
        "email": "william.costa.canin@gmail.com",
        "website": "https://williamcanin.github.io",
        "github": "https://github.com/williamcanin",
    },
    "credence": [
        {
            "my_name": "William C. Canin",
            "email": "william.costa.canin@gmail.com",
            "website": "http://williamcanin.me",
            "locale": "Brazil - SP",
        }
    ],
}



import sys
import snakypy
import tomlkit
from zshpower import HOME
from zshpower.sections.command import Command
from zshpower.sections.directory import Directory
from zshpower.sections.git import Git
from zshpower.sections.hostname import Hostname
from zshpower.sections.package import PyProject
from zshpower.sections.python import Python
from zshpower.sections.timer import Timer
from zshpower.sections.username import Username
from zshpower.sections.virtualenv import Virtualenv
from zshpower.zshpower import ZSHPower


class Prompt:
    """Class to perform the impression of the PROMPT style"""

    def __init__(self):
        self.zp = ZSHPower(HOME)

    @property
    def config(self):
        try:
            read_conf = snakypy.file.read(self.zp.config)
            parsed = tomlkit.parse(read_conf)
            return parsed
        except FileNotFoundError:
            self.zp.init_command()
            read_conf = snakypy.file.read(self.zp.config)
            parsed = tomlkit.parse(read_conf)
            snakypy.printer(
                f"[ZSHPower Warning] A new configuration file for that version "
                f'has been created in "{snakypy.FG.GREEN}{self.zp.config_root}{snakypy.ansi.NONE}".',
                foreground=snakypy.FG.YELLOW,
            )
            return parsed

    def left(self, jump_line="\n"):
        if not self.config["general"]["jump_line"]["enable"]:
            jump_line = ""
        username = Username(self.config)
        hostname = Hostname(self.config)
        directory = Directory(self.config)
        dinamic_section = {
            "package": PyProject(self.config),
            "python": Python(self.config),
            "virtualenv": Virtualenv(self.config),
            "git": Git(self.config),
        }
        cmd = Command(self.config)

        static_section = f"{jump_line}{username}{hostname}{directory}"

        ordered_section = []
        for element in self.config["general"]["position"]:
            for item in dinamic_section.keys():
                if item == element:
                    # sys.stdout.write(str(dinamic_section[item]))
                    ordered_section.append(dinamic_section[item])
        sections = "{}{}{}{}{}{}"
        return sections.format(static_section, *ordered_section, cmd)

    def right(self):
        timer = str(Timer(self.config))
        return timer


def main():
    if len(sys.argv) >= 1 and sys.argv[1] == "prompt":
        sys.stdout.write(Prompt().left())
    elif len(sys.argv) >= 1 and sys.argv[1] == "rprompt":
        sys.stdout.write(Prompt().right())



from datetime import datetime
from zshpower import __version__, __pkginfo__


def config_content():
    date_format = datetime.today().isoformat()
    data = f"""# Generate by: ZSHPower - D{date_format}
# Version: {__version__}
# ---------------------------------------------------------------------
# For more information, see the documentation at:
# https://github.com/snakypy/zshpower#configuration-file

[general]
jump_line.enable = true
separator.element = "-"
separator.color = "white"
position = ["package", "virtualenv", "python", "git"]

[username]
enable = false
color = "cyan"

[hostname]
enable = false
color = "magenta"
prefix.color = "green"
prefix.text = "at"

[directory]
truncation_length = 2
symbol = "\\ufc6e"
color = "cyan"
prefix.color = "green"
prefix.text = "in"

[git]
enable = true
symbol = "\\uf418"
branch.color = "cyan"
color.symbol = "white"
prefix.color = "green"
prefix.text = "on"

[git.status]
symbols.enable = true
symbol.clean = "\\uf62c"
symbol.added = "\\ufc03"
symbol.modified = "\\ufba8"
symbol.deleted = "\\ufbc7"
symbol.renamed = "\\uf101"
symbol.unmerged = "\\uf6fb"
symbol.untracked = "\\uf41e"
symbol.copied = "\\ufab1"
symbol.ahead = "\\uf55c"
symbol.behind = "\\uf544"
symbol.diverged = "\\ufb15"
symbol.conflicts = "\\uf0e7"

[command]
new_line.enable = true
symbol = "\\uf553"
color = "green"

[pyproject]
enable = true
symbol = "\\uf8d6"
color = "red"
prefix.color = "green"
prefix.text = "on"

[python]
symbol = "\\uf81f"
color = "yellow"
prefix.color = "green"
prefix.text = "via"
version.enable = true
version.micro.enable = true

[virtualenv]
enable = true
symbol = "\\uf10c"
involved = "()"
color = "yellow"
prefix.color = "green"
prefix.text = "via"

[virtualenv.name]
normal.enable = true
text = "venv"

[timer]
enable = true
symbol = "\\uf43a"
color = "blue"
seconds.enable = false
"""
    return data


def zshrc_content(omz_root):
    data = f"""# Generate by: ZSHPower
# If you come from bash you might have to change your $PATH.
# export PATH=$HOME/bin:/usr/local/bin:$PATH

# Path to your oh-my-zsh installation.
export ZSH="{omz_root}"

# Set name of the theme to load --- if set to "random", it will
# load a random theme each time oh-my-zsh is loaded, in which case,
# to know which specific one was loaded, run: echo $RANDOM_THEME
# See https://github.com/ohmyzsh/ohmyzsh/wiki/Themes
ZSH_THEME="{__pkginfo__['pkg_name']}"

# Set list of themes to pick from when loading at random
# Setting this variable when ZSH_THEME=random will cause zsh to load
# a theme from this variable instead of looking in ~/.oh-my-zsh/themes/
# If set to an empty array, this variable will have no effect.
# ZSH_THEME_RANDOM_CANDIDATES=( "robbyrussell" "agnoster" )

# Uncomment the following line to use case-sensitive completion.
# CASE_SENSITIVE="true"

# Uncomment the following line to use hyphen-insensitive completion.
# Case-sensitive completion must be off. _ and - will be interchangeable.
# HYPHEN_INSENSITIVE="true"

# Uncomment the following line to disable bi-weekly auto-update checks.
# DISABLE_AUTO_UPDATE="true"

# Uncomment the following line to automatically update without prompting.
# DISABLE_UPDATE_PROMPT="true"

# Uncomment the following line to change how often to auto-update (in days).
# export UPDATE_ZSH_DAYS=13

# Uncomment the following line if pasting URLs and other text is messed up.
# DISABLE_MAGIC_FUNCTIONS=true

# Uncomment the following line to disable colors in ls.
# DISABLE_LS_COLORS="true"

# Uncomment the following line to disable auto-setting terminal title.
# DISABLE_AUTO_TITLE="true"

# Uncomment the following line to enable command auto-correction.
# ENABLE_CORRECTION="true"

# Uncomment the following line to display red dots whilst waiting for
# completion.
# COMPLETION_WAITING_DOTS="true"

# Uncomment the following line if you want to disable marking untracked files
# under VCS as dirty. This makes repository status check for large
# repositories much, much faster.
# DISABLE_UNTRACKED_FILES_DIRTY="true"

# Uncomment the following line if you want to change the command execution
# time stamp shown in the history command output.
# You can set one of the optional three formats:
# "mm/dd/yyyy"|"dd.mm.yyyy"|"yyyy-mm-dd"
# or set a custom format using the strftime function format specifications,
# see 'man strftime' for details.
# HIST_STAMPS="mm/dd/yyyy"

# Would you like to use another custom folder than $ZSH/custom?
# ZSH_CUSTOM=/path/to/new-custom-folder

# Which plugins would you like to load?
# Standard plugins can be found in ~/.oh-my-zsh/plugins/*
# Custom plugins may be added to ~/.oh-my-zsh/custom/plugins/
# Example format: plugins=(rails git textmate ruby lighthouse)
# Add wisely, as too many plugins slow down shell startup.
plugins=(git python django pip pep8 autopep8)

source $ZSH/oh-my-zsh.sh

# User configuration

# export MANPATH="/usr/local/man:$MANPATH"

# You may need to manually set your language environment
# export LANG=en_US.UTF-8

# Preferred editor for local and remote sessions
# if [[ -n $SSH_CONNECTION ]]; then
#   export EDITOR='vim'
# else
#   export EDITOR='mvim'
# fi

# Compilation flags
# export ARCHFLAGS="-arch x86_64"

# Set personal aliases, overriding those provided by oh-my-zsh libs,
# plugins, and themes. Aliases can be placed here, though oh-my-zsh
# users are encouraged to define aliases within the ZSH_CUSTOM folder.
# For a full list of active aliases, run `alias`.
#
# Example aliases
# alias zshconfig="mate ~/.zshrc"
# alias ohmyzsh="mate ~/.oh-my-zsh"
    """
    return data


def theme_content():
    author = __pkginfo__["author"]["name"]
    website_author = __pkginfo__["author"]["website"]
    email = __pkginfo__["author"]["email"]
    content = f"""#!/usr/bin/env zsh

# Information:
# ******************************************************************************
# Theme: {__pkginfo__["name"]}
# Description: {__pkginfo__["description"]}
# Author: {author}, {website_author}

# LICENSE:
#    MIT License
#
#    Copyright (c) 2020-present {author} <{email}>
#
#    Permission is hereby granted, free of charge, to any person obtaining a copy
#    of this software and associated documentation files (the "Software"), to deal
#    in the Software without restriction, including without limitation the rights
#    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#    copies of the Software, and to permit persons to whom the Software is
#    furnished to do so, subject to the following conditions:
#
#    The above copyright notice and this permission notice shall be included in all
#    copies or substantial portions of the Software.
#
#    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#    SOFTWARE.
# ******************************************************************************

function set_zshpower () {{
    PROMPT="$(zshpower-shell prompt)"
    RPROMPT="$(zshpower-shell rprompt)"
}}
autoload add-zsh-hook
add-zsh-hook precmd set_zshpower
    """
    return content
